==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/firstrunwizard/l10n/ru.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Добро пожаловать в %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Ваши персональные веб сервисы. Все файлы, контакты, календарь и многое другое в одном месте.",
"Get the apps to sync your files" => "Получить приложения для синхронизации ваших файлов",
"Desktop client" => "Клиент для ПК",
"Android app" => "Android приложение",
"iOS app" => "iOS приложение",
"Connect your desktop apps to %s" => "Подключите приложения с компьютера к %s",
"Connect your Calendar" => "Подключите свой календарь",
"Connect your Contacts" => "Подключите свои контакты",
"Access files via WebDAV" => "Доступ к файлам через WebDAV",
"Documentation" => "Документация",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Более подробная информация в <a target=\"_blank\" href=\"%s\">документации</a> и на нашем <a target=\"_blank\" href=\"http://owncloud.org\">сайте</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Если Вам нравится ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud – открытое программное обеспечение для синхронизации и совместного использования ваших файлов. \n\t\tВы можете скачать его бесплатно на http://owncloud.org\">\n\t\tпорекомендуйте его друзьям</a>\n\tи <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">расскажите всем</a>!"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/firstrunwizard/l10n/ru.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Добро пожаловать в %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Ваши персональные веб сервисы. Все файлы, контакты, календарь и многое другое в одном месте.",
"Get the apps to sync your files" => "Получить приложения для синхронизации ваших файлов",
"Desktop client" => "Клиент для ПК",
"Android app" => "Android приложение",
"iOS app" => "iOS приложение",
"Connect your desktop apps to %s" => "Подключите приложения с компьютера к %s",
"Connect your Calendar" => "Подключите свой календарь",
"Connect your Contacts" => "Подключите свои контакты",
"Access files via WebDAV" => "Доступ к файлам через WebDAV",
"Documentation" => "Документация",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Более подробная информация в <a target=\"_blank\" href=\"%s\">документации</a> и на нашем <a target=\"_blank\" href=\"http://owncloud.org\">сайте</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Если Вам нравится ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud – открытое программное обеспечение для синхронизации и совместного использования ваших файлов. \n\t\tВы можете скачать его бесплатно на http://owncloud.org\">\n\t\tпорекомендуйте его друзьям</a>\n\tи <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">расскажите всем</a>!"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);";
